@@ -1,5 +1,5 @@
 import importlib
-from typing import List, Type
+from typing import Any, Dict, List, Optional, Type
 
 import h5py
 import ipyvolume as ipv
@@ -14,14 +14,11 @@ from IPython.display import Markdown, Math, display
 
 from popsynth.utils.array_to_cmap import array_to_cmap
 from popsynth.utils.hdf5_utils import (
-    clean_graph_dict,
-    fill_graph_dict,
+    clean_graph_dict, fill_graph_dict,
     recursively_load_dict_contents_from_group,
-    recursively_save_dict_contents_to_group,
-)
-from popsynth.utils.spherical_geometry import xyz
-
+    recursively_save_dict_contents_to_group)
 from popsynth.utils.logging import setup_logger
+from popsynth.utils.spherical_geometry import xyz
 
 log = setup_logger(__name__)
 
@@ -48,23 +45,20 @@ class Population(object):
         selection: ArrayLike,
         flux_sigma: float,
         r_max: float,
-        boundary: float,
-        strength: float,
         n_model: int,
-        lf_params: dict,
-        spatial_params: dict = None,
-        model_spaces=None,
+        lf_params: Dict[str, Any],
+        spatial_params: Optional[Dict[str, Any]] = None,
+        model_spaces: Optional[ArrayLike] = None,
         seed: int = 1234,
-        name: str = None,
-        spatial_form: dict = None,
-        lf_form: dict = None,
-        auxiliary_quantities: dict = None,
-        truth: dict = {},
-        hard_cut: bool = False,
-        distance_probability: float = 1.0,
-        graph=None,
+        name: Optional[str] = None,
+        spatial_form: Optional[Dict[str, Any]] = None,
+        lf_form: Optional[Dict[str, Any]] = None,
+        auxiliary_quantities: Optional[Dict[str, Any]] = None,
+        truth: Dict[str, float] = {},
+        graph: Optional[Dict[str, Any]] = None,
         theta=None,
         phi=None,
+        pop_synth: Optional[Dict[str, Any]] = None
     ) -> None:
         """
         A population containing all the simulated variables
@@ -79,8 +73,6 @@ class Population(object):
         :param selection: the selection vector
         :param flux_sigma: the uncertainty on the observed flux
         :param r_max: the maximum distance of the survey
-        :param boundary: the flux boundary
-        :param strength: the strength of the sofft boundary
         :param n_model:
         :param lf_params:
         :param spatial_params:
@@ -91,8 +83,6 @@ class Population(object):
         :param lf_form:
         :param auxiliary_quantities:
         :param truth:
-        :param hard_cut:
-        :param distance_probability:
         :returns:
         :rtype:
 
@@ -119,9 +109,6 @@ class Population(object):
         self._flux_sigma = flux_sigma  # type: float
 
         self._r_max = r_max  # type: float
-
-        self._boundary = boundary  # type: float
-        self._strength = strength  # type: float
         self._seed = seed  # type: int
         self._n_model = n_model  # type: int
         self._name = name  # type: str
@@ -143,15 +130,14 @@ class Population(object):
 
         self._truth = truth
 
-        self._hard_cut = hard_cut  # type: bool
-        self._distance_probability = distance_probability  # type: float
-
         self._graph = graph
 
         self._n_objects = len(selection)  # type: int
         self._n_detections = sum(self._selection)  # type: int
         self._n_non_detections = self._n_objects - self._n_detections  # type: int
 
+        self._pop_synth: Optional[Dict[str, Any]] = pop_synth
+
         if self._n_detections == 0:
 
             self._no_detection = True
@@ -182,6 +168,13 @@ class Population(object):
     def graph(self):
         return self._graph
 
+    @property
+    def pop_synth(self) -> Dict[str, Any]:
+        """
+        Dictionary population synth used to create this population
+        """
+        return self._pop_synth
+
     @property
     def truth(self):
         """
@@ -194,30 +187,11 @@ class Population(object):
 
         return self._truth
 
-    @property
-    def boundary(self) -> float:
-        return self._boundary
-
     @property
     def flux_sigma(self) -> float:
 
         return self._flux_sigma
 
-    @property
-    def strength(self) -> float:
-
-        return self._strength
-
-    @property
-    def distance_probabilty(self) -> float:
-        if self._distance_probabilty is None:
-
-            return 1.0
-
-        else:
-
-            return self._distance_probability
-
     @property
     def theta(self) -> np.ndarray:
         return self._theta
@@ -399,8 +373,6 @@ class Population(object):
             z_max=self._r_max,
             r_max=self._r_max,
             N_model=self._n_model,
-            boundary=self._boundary,
-            strength=self._strength,
         )
 
         # now append the model spaces
@@ -483,11 +455,7 @@ class Population(object):
         f.attrs["flux_sigma"] = self._flux_sigma
         f.attrs["n_model"] = self._n_model
         f.attrs["r_max"] = self._r_max
-        f.attrs["boundary"] = self._boundary
-        f.attrs["strength"] = self._strength
         f.attrs["seed"] = int(self._seed)
-        f.attrs["distance_probability"] = self._distance_probability
-        f.attrs["hard_cut"] = self._hard_cut
 
         f.create_dataset("luminosities",
                          data=self._luminosities,
@@ -534,6 +502,10 @@ class Population(object):
         recursively_save_dict_contents_to_group(
             f, "graph", fill_graph_dict(nx.to_dict_of_dicts(self._graph)))
 
+        recursively_save_dict_contents_to_group(f, "popsynth", self._pop_synth)
+
+        # now store the popsymnth
+
     @classmethod
     def from_file(cls, file_name):
         """
@@ -596,15 +568,12 @@ class Population(object):
             lf_form = None
 
         flux_sigma = f.attrs["flux_sigma"]
-        boundary = f.attrs["boundary"]
-        strength = f.attrs["strength"]
         n_model = f.attrs["n_model"]
         r_max = f.attrs["r_max"]
         seed = int(f.attrs["seed"])
         name = f.attrs["name"]
-        distance_probability = f.attrs["distance_probability"]
+
         spatial_form = str(f.attrs["spatial_form"])
-        hard_cut = f.attrs["hard_cut"]
 
         luminosities = f["luminosities"][()]
         distances = f["distances"][()]
@@ -648,6 +617,8 @@ class Population(object):
             clean_graph_dict(
                 recursively_load_dict_contents_from_group(f, "graph")))
 
+        pop_synth = recursively_load_dict_contents_from_group(f, "popsynth")
+
         return cls(
             luminosities=luminosities,
             distances=distances,
@@ -660,8 +631,6 @@ class Population(object):
             flux_sigma=flux_sigma,
             n_model=n_model,
             r_max=r_max,
-            boundary=boundary,
-            strength=strength,
             lf_params=lf_params,
             spatial_params=spatial_params,
             model_spaces=model_spaces,
@@ -671,11 +640,10 @@ class Population(object):
             lf_form=lf_form,
             auxiliary_quantities=auxiliary_quantities,
             truth=truth,
-            distance_probability=distance_probability,
-            hard_cut=hard_cut,
             graph=graph,
             theta=theta,
             phi=phi,
+            pop_synth=pop_synth
         )
 
     def to_sub_population(self, observed: bool = True) -> "Population":
@@ -741,8 +709,6 @@ class Population(object):
             flux_sigma=self._flux_sigma,
             n_model=self._n_model,
             r_max=self._r_max,
-            boundary=self._boundary,
-            strength=self._strength,
             lf_params=self._lf_params,
             spatial_params=self._spatial_params,
             model_spaces=self._model_spaces,
@@ -752,8 +718,6 @@ class Population(object):
             lf_form=self._lf_form,
             auxiliary_quantities=new_aux,
             truth=self._truth,
-            distance_probability=self._distance_probability,
-            hard_cut=self._hard_cut,
             graph=self._graph,
             theta=self._theta[selection],
             phi=self._phi[selection],
@@ -824,7 +788,7 @@ class Population(object):
             **kwargs,
         )
 
-        ax.axhline(self._boundary, color="grey", zorder=-5000, ls="--")
+#        ax.axhline(self._boundary, color="grey", zorder=-5000, ls="--")
 
         # ax.set_xscale('log')
         ax.set_yscale("log")
@@ -883,7 +847,7 @@ class Population(object):
             **kwargs,
         )
 
-        ax.axhline(self._boundary, color="grey", zorder=-5000, ls="--")
+#        ax.axhline(self._boundary, color="grey", zorder=-5000, ls="--")
         # ax.set_xscale('log')
         ax.set_yscale("log")
 
@@ -1042,10 +1006,10 @@ class Population(object):
             fig.controls = control
             control.autoRotate = True
             fig.render_continuous = True
-            control.autoRotate = True
-            toggle_rotate = widgets.ToggleButton(description="Rotate")
-            widgets.jslink((control, "autoRotate"), (toggle_rotate, "value"))
-            r_value = toggle_rotate
+            #control.autoRotate = True
+            # toggle_rotate = widgets.ToggleButton(description="Rotate")
+            # widgets.jslink((control, "autoRotate"), (toggle_rotate, "value"))
+            # r_value = toggle_rotate
 
         return fig
 
