@@ -4,6 +4,9 @@ from .selection_probability import SelectionProbabilty
 
 
 class SpatialSelection(SelectionProbabilty):
+
+    _selection_name = "SpatialSelection"
+
     def __init__(self, name) -> None:
 
         super(SpatialSelection, self).__init__(name)
@@ -18,3 +21,6 @@ class SpatialSelection(SelectionProbabilty):
         assert isinstance(spatial_distribtuion, SpatialDistribution)
 
         self._spatial_distribution: SpatialDistribution = spatial_distribtuion
+
+
+__all__ = ["SpatialSelection"]
