@@ -1,16 +1,18 @@
-import numpy as np
-import h5py
 import os
 
+import h5py
+import numpy as np
+
 
 def recursively_save_dict_contents_to_group(h5file, path, dic):
     """
-    ....
+    load files from hdf5
+
     """
     for key, item in dic.items():
         if isinstance(
-                item,
-            (np.ndarray, np.int64, np.float64, str, bytes, float, int)):
+            item,
+                (np.ndarray, np.int64, np.float64, str, bytes, float, int)):
             h5file[path + "/" + key] = item
         elif isinstance(item, dict):
             recursively_save_dict_contents_to_group(h5file,
@@ -22,7 +24,7 @@ def recursively_save_dict_contents_to_group(h5file, path, dic):
 
 def recursively_load_dict_contents_from_group(h5file, path):
     """
-    ....
+    load files from hdf5
     """
     ans = {}
 
