@@ -96,6 +96,82 @@ popsynth_console_log_handler.setLevel(
 warning_filter = MyFilter(logging.WARNING)
 
 
+
+class LoggingState(object):
+
+    def __init__(self, popsynth_usr_log_handler, popsynth_console_log_handler,
+       
+                 ):
+        """
+        A container to store the stat of the logs
+        """
+
+        # attach the log handlers
+
+        self.popsynth_usr_log_handler = popsynth_usr_log_handler
+        self.popsynth_console_log_handler = popsynth_console_log_handler
+
+
+        # store their current states
+
+        self.popsynth_usr_log_handler_state = popsynth_usr_log_handler.level
+        self.popsynth_console_log_handler_state = popsynth_console_log_handler.level
+
+    def _store_state(self):
+
+        self.popsynth_usr_log_handler_state = popsynth_usr_log_handler.level
+        self.popsynth_console_log_handler_state = popsynth_console_log_handler.level
+
+
+    def restore_last_state(self):
+
+        self.popsynth_usr_log_handler.setLevel(
+            self.popsynth_usr_log_handler_state)
+        self.popsynth_console_log_handler.setLevel(
+            self.popsynth_console_log_handler_state)
+
+    def silence_logs(self):
+
+        # store the state
+        self._store_state()
+
+        # silence the logs
+
+        self.popsynth_usr_log_handler.setLevel(
+            logging.CRITICAL)
+        self.popsynth_console_log_handler.setLevel(
+            logging.CRITICAL)
+
+
+    def loud_logs(self):
+
+        # store the state
+        self._store_state()
+
+        # silence the logs
+
+        self.popsynth_usr_log_handler.setLevel(
+            logging.INFO)
+        self.popsynth_console_log_handler.setLevel(
+            logging.INFO)
+
+    def debug_logs(self):
+
+        # store the state
+        self._store_state()
+
+        # silence the logs
+        self.popsynth_console_log_handler.setLevel(
+            logging.DEBUG)
+
+
+
+_log_state = LoggingState(popsynth_usr_log_handler, popsynth_console_log_handler,
+                          )
+
+
+
+
 def silence_warnings():
     """
     supress warning messages in console and file usr logs
@@ -119,6 +195,76 @@ def update_logging_level(level):
     popsynth_console_log_handler.setLevel(level)
 
 
+def silence_logs():
+    """
+    Turn off all logging
+    """
+
+    # handle dev logs independently
+    popsynth_dev_log_handler.setLevel(logging.CRITICAL)
+
+
+    _log_state.silence_logs()
+
+
+def show_progress_bars():
+
+    popsynth_config.show_progress = True
+
+
+def silence_progress_bars():
+
+    popsynth_config.show_progress = False
+
+
+
+    
+def quiet_mode():
+    """
+    turn off all logging and progress bars
+    """
+
+    silence_progress_bars()
+
+    # save state and silence
+    silence_logs()
+
+
+def loud_mode():
+    """
+    turn on all progress bars and logging
+    """
+
+    show_progress_bars()
+
+    # save state and make loud
+    _log_state.loud_logs()
+
+
+def activate_logs():
+    """
+    re-activate silenced logs
+    """
+
+    # handle dev logs independently
+    popsynth_dev_log_handler.setLevel(logging.DEBUG)
+
+
+    _log_state.restore_last_state()
+
+
+def debug_mode():
+    """
+    activate debug in the console
+    """
+
+    # store state and switch console to debug
+    _log_state.debug_logs()
+
+    
+
+
+    
 @contextmanager
 def silence_console_log():
 
@@ -137,15 +283,6 @@ def silence_console_log():
         popsynth_usr_log_handler.setLevel(current_usr_logging_level)
 
 
-def show_progress():
-
-    popsynth_config["show_progress"] = True
-
-
-def silence_progress():
-
-    popsynth_config["show_progress"] = False
-
 
 def setup_logger(name):
 
