@@ -3,10 +3,11 @@ import pkg_resources
 
 from popsynth.utils.configuration import popsynth_config
 
-# def get_path_of_data_file(data_file) -> Path:
-#     file_path = pkg_resources.resource_filename("popsynth", "data/%s" % data_file)
+def get_path_of_data_file(data_file) -> Path:
+    file_path = pkg_resources.resource_filename("popsynth", "data/%s" % data_file)
+
+    return Path(file_path)
 
-#     return Path(file_path)
 
 
 def get_path_of_log_dir() -> Path:
